@@ -2,9 +2,11 @@
 
 from strangeworks.annealing.annealing import Annealing
 from .auth import auth
-from .VERSION import VERSION as __version__
-from .client import Client
 
+from .client import Client
+import importlib.metadata
+
+__version__ = importlib.metadata.version("strangeworks")
 
 # SUBMODULES = [
 #     "blueqat",
