@@ -66,7 +66,10 @@ class Job:
                 if self.__status == self.COMPLETED and "sdkResult" in response:
                     sdk_results = response["sdkResult"]
                     if "data" in sdk_results:
-                        self.__results = json.loads(sdk_results["data"])
+                        if isinstance(sdk_results["data"], dict):
+                            self.__results = sdk_results["data"]
+                        else:
+                            self.__results = json.loads(sdk_results["data"])
             time.sleep(wait)
             if self.__wait_timeout is not None and (
                 (datetime.datetime.now().second - start_time.second)
