@@ -2,11 +2,12 @@ import os, yaml
 
 from strangeworks.annealing.annealing import Annealing
 from strangeworks.circuit_runner.circuit_runner import CircuitRunner
-
-
-from . import __version__
 from strangeworks.rest_client.rest_client import StrangeworksRestClient
 
+import importlib.metadata
+
+__version__ = importlib.metadata.version("strangeworks")
+
 
 class Client(object):
     """Strangeworks client implements the Strangeworks API and provides core functionality for cross-vendor applications"""
